snowland-image
==============

|version| |gitee| |github| |download| |wheel| |status|

参考资料
~~~~~~~~

[1] https://github.com/ASTARCHEN/astartool

[2] https://github.com/astar-club/astar-devopstool-python

.. |version| image:: https://img.shields.io/pypi/v/snowland-image.svg
   :target: https://pypi.python.org/pypi/snowland-image
.. |gitee| image:: https://gitee.com/snowlandltd/scikit-snowland/badge/star.svg
   :target: https://gitee.com/snowlandltd/scikit-snowland/stargazers
.. |github| image:: https://img.shields.io/github/stars/astar-club/scikit-snowland
   :target: https://img.shields.io/github/stars/astar-club/scikit-snowland
.. |download| image:: https://img.shields.io/pypi/dm/snowland-image.svg
   :target: https://pypi.org/project/snowland-image
.. |wheel| image:: https://img.shields.io/pypi/wheel/snowland-image.svg
   :target: https://pypi.python.org/pypi/snowland-image
.. |status| image:: https://img.shields.io/pypi/status/snowland-image.svg
